==> flutter_jiopay_pg-0.0.5.tar.gz: android/src/main/java/com/jiopay/flutter_jiopay_pg/JiopayDelegate.java <==
package com.jiopay.flutter_jiopay_pg;

import android.app.Activity;
import android.content.Intent;
import android.util.Log;


import com.jfs.webinterface.activity.Checkout;
import com.jfs.webinterface.callbacks.PaymentResultListener;

import org.json.JSONException;
import org.json.JSONObject;

import java.util.HashMap;
import java.util.Map;

import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.ActivityResultListener;

public class JiopayDelegate implements  PaymentResultListener {

    private final Activity activity;
    private Result pendingResult;
    private Map<String, Object> pendingReply;

    private static final int CODE_PAYMENT_SUCCESS = 0;
    private static final int CODE_PAYMENT_ERROR = 1;



    public JiopayDelegate(Activity activity) {
        this.activity = activity;
    }

    void openCheckout(Map<String, Object> arguments, Result result) {
        this.pendingResult = result;
        JSONObject options = new JSONObject(arguments);
        Checkout.open(activity,this,options);
    }

    private void sendReply(Map<String, Object> data) {
        if (pendingResult != null) {
            pendingResult.success(data);
            pendingReply = null;
        } else {
            pendingReply = data;
        }
    }
    public void resync(Result result) {
        result.success(pendingReply);
        pendingReply = null;
    }

    @Override
    public void onPaymentSuccess(String jfsPaymentID, String intentId) {
        Map<String, Object> reply = new HashMap<>();
        reply.put("type", CODE_PAYMENT_SUCCESS);
        Map<String, Object> data = new HashMap<>();
        data.put("tnxId",jfsPaymentID);
        data.put("intentId", intentId);
        reply.put("data", data);
        sendReply(reply);
    }

    @Override
    public void onPaymentError(String code, String error) {
        Map<String, Object> reply = new HashMap<>();
        reply.put("type", CODE_PAYMENT_ERROR);
        Map<String, Object> data = new HashMap<>();
        data.put("code", (code));
        data.put("message", error);
        reply.put("data", data);
        sendReply(reply);
    }
}

==> flutter_jiopay_pg-0.0.6.tar.gz: android/src/main/java/com/jiopay/flutter_jiopay_pg/JiopayDelegate.java <==
package com.jiopay.flutter_jiopay_pg;

import android.app.Activity;
import android.content.Intent;
import android.util.Log;


import com.jfs.webinterface.activity.Checkout;
import com.jfs.webinterface.callbacks.PaymentResultListener;

import org.json.JSONException;
import org.json.JSONObject;

import java.util.HashMap;
import java.util.Map;

import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.ActivityResultListener;

public class JiopayDelegate implements  PaymentResultListener {

    private final Activity activity;
    private Result pendingResult;
    private Map<String, Object> pendingReply;

    private static final int CODE_PAYMENT_SUCCESS = 0;
    private static final int CODE_PAYMENT_ERROR = 1;



    public JiopayDelegate(Activity activity) {
        this.activity = activity;
    }

    void openCheckout(Map<String, Object> arguments, Result result) {
        this.pendingResult = result;
        JSONObject options = new JSONObject(arguments);
        Checkout.open(activity,this,options);
    }

    private void sendReply(Map<String, Object> data) {
        if (pendingResult != null) {
            pendingResult.success(data);
            pendingReply = null;
        } else {
            pendingReply = data;
        }
    }
    public void resync(Result result) {
        result.success(pendingReply);
        pendingReply = null;
    }

    @Override
    public void onPaymentSuccess(String jfsPaymentID, String intentId) {
        Map<String, Object> reply = new HashMap<>();
        reply.put("type", CODE_PAYMENT_SUCCESS);
        Map<String, Object> data = new HashMap<>();
        data.put("tnxId",jfsPaymentID);
        data.put("intentId", intentId);
        reply.put("data", data);
        sendReply(reply);
    }

    @Override
    public void onPaymentError(String code, String error, String intentId) {
        Map<String, Object> reply = new HashMap<>();
        reply.put("type", CODE_PAYMENT_ERROR);
        Map<String, Object> data = new HashMap<>();
        data.put("code", (code));
        data.put("message", error);
        data.put("intentId", intentId);
        reply.put("data", data);
        sendReply(reply);

    }
}
